==> dao-2.0.0-alpha.3-sources.jar: org/n52/series/db/da/ProcedureRepository.java <==
/*
 * Copyright (C) 2015-2017 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation.
 *
 * If the program is linked with libraries which are licensed under one of
 * the following licenses, the combination of the program with the linked
 * library is not considered a "derivative work" of the program:
 *
 *     - Apache License, version 2.0
 *     - Apache Software License, version 1.0
 *     - GNU Lesser General Public License, version 3
 *     - Mozilla Public License, versions 1.0, 1.1 and 2.0
 *     - Common Development and Distribution License (CDDL), version 1.0
 *
 * Therefore the distribution of the program linked with libraries licensed
 * under the aforementioned licenses, is permitted by the copyright holders
 * if the distribution is compliant with both the GNU General Public License
 * version 2 and the aforementioned licenses.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 */

package org.n52.series.db.da;

import java.util.Collections;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import org.hibernate.Session;
import org.n52.io.response.ProcedureOutput;
import org.n52.io.response.ServiceOutput;
import org.n52.series.db.beans.ProcedureEntity;
import org.n52.series.db.dao.DbQuery;
import org.n52.series.db.dao.ProcedureDao;
import org.n52.series.db.dao.SearchableDao;
import org.n52.series.spi.search.FeatureSearchResult;
import org.n52.series.spi.search.SearchResult;

public class ProcedureRepository extends HierarchicalParameterRepository<ProcedureEntity, ProcedureOutput> {

    @Override
    protected ProcedureOutput prepareEmptyParameterOutput(ProcedureEntity entity) {
        return new ProcedureOutput();
    }

    @Override
    protected SearchResult createEmptySearchResult(String id, String label, String baseUrl) {
        return new FeatureSearchResult(id, label, baseUrl);
    }

    @Override
    protected String createHref(String hrefBase) {
        return urlHelper.getProceduresHrefBaseUrl(hrefBase);
    }

    @Override
    protected ProcedureDao createDao(Session session) {
        return new ProcedureDao(session);
    }

    @Override
    protected SearchableDao<ProcedureEntity> createSearchableDao(Session session) {
        return new ProcedureDao(session);
    }

    @Override
    protected ProcedureOutput createExpanded(ProcedureEntity entity, DbQuery query, Session session) {
        ProcedureOutput result = createCondensed(entity, query, session);
        ServiceOutput service = (query.getHrefBase() != null)
                ? getCondensedExtendedService(getServiceEntity(entity), query)
                : getCondensedService(getServiceEntity(entity), query);
        result.setValue(ProcedureOutput.SERVICE, service, query.getParameters(), result::setService);
        result.setParents(createCondensed(entity.getParents(), query, session));
        result.setChildren(createCondensed(entity.getChildren(), query, session));
        return result;
    }

    protected List<ProcedureOutput> createCondensedHierarchyMembers(Set<ProcedureEntity> members,
                                                                    DbQuery parameters,
                                                                    Session session) {
        return members == null
                ? Collections.emptyList()
                : members.stream()
                         .map(e -> createCondensed(e, parameters, session))
                         .collect(Collectors.toList());
    }

}

==> dao-3.0.0-alpha.3-sources.jar: org/n52/series/db/da/ProcedureRepository.java <==
/*
 * Copyright (C) 2015-2019 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation.
 *
 * If the program is linked with libraries which are licensed under one of
 * the following licenses, the combination of the program with the linked
 * library is not considered a "derivative work" of the program:
 *
 *     - Apache License, version 2.0
 *     - Apache Software License, version 1.0
 *     - GNU Lesser General Public License, version 3
 *     - Mozilla Public License, versions 1.0, 1.1 and 2.0
 *     - Common Development and Distribution License (CDDL), version 1.0
 *
 * Therefore the distribution of the program linked with libraries licensed
 * under the aforementioned licenses, is permitted by the copyright holders
 * if the distribution is compliant with both the GNU General Public License
 * version 2 and the aforementioned licenses.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 */
package org.n52.series.db.da;

import java.util.Collections;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import org.hibernate.Session;
import org.n52.io.response.AbstractOutput;
import org.n52.io.response.ProcedureOutput;
import org.n52.io.response.ServiceOutput;
import org.n52.series.db.beans.ProcedureEntity;
import org.n52.series.db.dao.DbQuery;
import org.n52.series.db.dao.ProcedureDao;
import org.n52.series.db.dao.SearchableDao;
import org.n52.series.spi.search.FeatureSearchResult;
import org.n52.series.spi.search.SearchResult;

public class ProcedureRepository extends HierarchicalParameterRepository<ProcedureEntity, ProcedureOutput> {

    @Override
    protected ProcedureOutput prepareEmptyParameterOutput() {
        return new ProcedureOutput();
    }

    @Override
    protected SearchResult createEmptySearchResult(String id, String label, String baseUrl) {
        return new FeatureSearchResult(id, label, baseUrl);
    }

    @Override
    protected ProcedureDao createDao(Session session) {
        return new ProcedureDao(session);
    }

    @Override
    protected SearchableDao<ProcedureEntity> createSearchableDao(Session session) {
        return new ProcedureDao(session);
    }

    @Override
    protected ProcedureOutput createExpanded(ProcedureEntity entity, DbQuery query, Session session) {
        ProcedureOutput result = createCondensed(entity, query, session);
        ServiceOutput service = (query.getHrefBase() != null)
                ? getCondensedExtendedService(getServiceEntity(entity), query.withoutFieldsFilter())
                : getCondensedService(getServiceEntity(entity), query.withoutFieldsFilter());
        result.setValue(AbstractOutput.SERVICE, service, query.getParameters(), result::setService);
        result.setParents(createCondensed(entity.getParents(), query, session));
        result.setChildren(createCondensed(entity.getChildren(), query, session));
        return result;
    }

    protected List<ProcedureOutput> createCondensedHierarchyMembers(Set<ProcedureEntity> members,
                                                                    DbQuery parameters,
                                                                    Session session) {
        return members == null
                ? Collections.emptyList()
                : members.stream()
                         .map(e -> createCondensed(e, parameters, session))
                         .collect(Collectors.toList());
    }

}
